**Now this is just for rests to upload and pull the package.**

Version: 0.0.0.0

Usage: python -m uvicorn treegear:trgr

And go in browser to http://127.0.0.1:8000

For any path it returns "OK and hello from TreeGear!"

You can make it return your own message if prior set environment variable $MESSAGE

